==> libgda-4.1.2.tar.bz2: libgda-4.1.2/libgda-ui/gdaui-enum-types.c <==

/* Generated data (by glib-mkenums) */

#include <libgda-ui/libgda-ui.h>
#include <glib-object.h>

/* enumerations from "gdaui-data-widget.h" */
GType
gdaui_data_widget_write_mode_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GDAUI_DATA_WIDGET_WRITE_ON_DEMAND, "GDAUI_DATA_WIDGET_WRITE_ON_DEMAND", "demand" },
      { GDAUI_DATA_WIDGET_WRITE_ON_ROW_CHANGE, "GDAUI_DATA_WIDGET_WRITE_ON_ROW_CHANGE", "row-change" },
      { GDAUI_DATA_WIDGET_WRITE_ON_VALUE_ACTIVATED, "GDAUI_DATA_WIDGET_WRITE_ON_VALUE_ACTIVATED", "value-activated" },
      { GDAUI_DATA_WIDGET_WRITE_ON_VALUE_CHANGE, "GDAUI_DATA_WIDGET_WRITE_ON_VALUE_CHANGE", "value-change" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GdauiDataWidgetWriteMode", values);
  }
  return etype;
}

/* enumerations from "gdaui-data-widget-info.h" */
GType
gdaui_data_widget_info_flag_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GFlagsValue values[] = {
      { GDAUI_DATA_WIDGET_INFO_NONE, "GDAUI_DATA_WIDGET_INFO_NONE", "none" },
      { GDAUI_DATA_WIDGET_INFO_CURRENT_ROW, "GDAUI_DATA_WIDGET_INFO_CURRENT_ROW", "current-row" },
      { GDAUI_DATA_WIDGET_INFO_ROW_MODIFY_BUTTONS, "GDAUI_DATA_WIDGET_INFO_ROW_MODIFY_BUTTONS", "row-modify-buttons" },
      { GDAUI_DATA_WIDGET_INFO_ROW_MOVE_BUTTONS, "GDAUI_DATA_WIDGET_INFO_ROW_MOVE_BUTTONS", "row-move-buttons" },
      { GDAUI_DATA_WIDGET_INFO_CHUNCK_CHANGE_BUTTONS, "GDAUI_DATA_WIDGET_INFO_CHUNCK_CHANGE_BUTTONS", "chunck-change-buttons" },
      { GDAUI_DATA_WIDGET_INFO_NO_FILTER, "GDAUI_DATA_WIDGET_INFO_NO_FILTER", "no-filter" },
      { 0, NULL, NULL }
    };
    etype = g_flags_register_static ("GdauiDataWidgetInfoFlag", values);
  }
  return etype;
}

/* enumerations from "gdaui-enums.h" */
GType
gdaui_action_mode_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GFlagsValue values[] = {
      { GDAUI_ACTION_NAVIGATION_ARROWS, "GDAUI_ACTION_NAVIGATION_ARROWS", "navigation-arrows" },
      { GDAUI_ACTION_NAVIGATION_SCROLL, "GDAUI_ACTION_NAVIGATION_SCROLL", "navigation-scroll" },
      { GDAUI_ACTION_MODIF_AUTO_COMMIT, "GDAUI_ACTION_MODIF_AUTO_COMMIT", "modif-auto-commit" },
      { GDAUI_ACTION_MODIF_COMMIT_IMMEDIATE, "GDAUI_ACTION_MODIF_COMMIT_IMMEDIATE", "modif-commit-immediate" },
      { GDAUI_ACTION_ASK_CONFIRM_UPDATE, "GDAUI_ACTION_ASK_CONFIRM_UPDATE", "ask-confirm-update" },
      { GDAUI_ACTION_ASK_CONFIRM_DELETE, "GDAUI_ACTION_ASK_CONFIRM_DELETE", "ask-confirm-delete" },
      { GDAUI_ACTION_ASK_CONFIRM_INSERT, "GDAUI_ACTION_ASK_CONFIRM_INSERT", "ask-confirm-insert" },
      { GDAUI_ACTION_REPORT_ERROR, "GDAUI_ACTION_REPORT_ERROR", "report-error" },
      { 0, NULL, NULL }
    };
    etype = g_flags_register_static ("GdauiActionMode", values);
  }
  return etype;
}
GType
gdaui_action_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GDAUI_ACTION_NEW_DATA, "GDAUI_ACTION_NEW_DATA", "new-data" },
      { GDAUI_ACTION_WRITE_MODIFIED_DATA, "GDAUI_ACTION_WRITE_MODIFIED_DATA", "write-modified-data" },
      { GDAUI_ACTION_DELETE_SELECTED_DATA, "GDAUI_ACTION_DELETE_SELECTED_DATA", "delete-selected-data" },
      { GDAUI_ACTION_UNDELETE_SELECTED_DATA, "GDAUI_ACTION_UNDELETE_SELECTED_DATA", "undelete-selected-data" },
      { GDAUI_ACTION_RESET_DATA, "GDAUI_ACTION_RESET_DATA", "reset-data" },
      { GDAUI_ACTION_MOVE_FIRST_RECORD, "GDAUI_ACTION_MOVE_FIRST_RECORD", "move-first-record" },
      { GDAUI_ACTION_MOVE_PREV_RECORD, "GDAUI_ACTION_MOVE_PREV_RECORD", "move-prev-record" },
      { GDAUI_ACTION_MOVE_NEXT_RECORD, "GDAUI_ACTION_MOVE_NEXT_RECORD", "move-next-record" },
      { GDAUI_ACTION_MOVE_LAST_RECORD, "GDAUI_ACTION_MOVE_LAST_RECORD", "move-last-record" },
      { GDAUI_ACTION_MOVE_FIRST_CHUNCK, "GDAUI_ACTION_MOVE_FIRST_CHUNCK", "move-first-chunck" },
      { GDAUI_ACTION_MOVE_PREV_CHUNCK, "GDAUI_ACTION_MOVE_PREV_CHUNCK", "move-prev-chunck" },
      { GDAUI_ACTION_MOVE_NEXT_CHUNCK, "GDAUI_ACTION_MOVE_NEXT_CHUNCK", "move-next-chunck" },
      { GDAUI_ACTION_MOVE_LAST_CHUNCK, "GDAUI_ACTION_MOVE_LAST_CHUNCK", "move-last-chunck" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GdauiAction", values);
  }
  return etype;
}

/* enumerations from "gdaui-login.h" */
GType
gdaui_login_mode_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GFlagsValue values[] = {
      { GDA_UI_LOGIN_ENABLE_CONTROL_CENTRE_MODE, "GDA_UI_LOGIN_ENABLE_CONTROL_CENTRE_MODE", "enable-control-centre-mode" },
      { GDA_UI_LOGIN_HIDE_DSN_SELECTION_MODE, "GDA_UI_LOGIN_HIDE_DSN_SELECTION_MODE", "hide-dsn-selection-mode" },
      { GDA_UI_LOGIN_HIDE_DIRECT_CONNECTION_MODE, "GDA_UI_LOGIN_HIDE_DIRECT_CONNECTION_MODE", "hide-direct-connection-mode" },
      { 0, NULL, NULL }
    };
    etype = g_flags_register_static ("GdauiLoginMode", values);
  }
  return etype;
}

/* Generated data ends here */

==> libgda-4.1.10.tar.bz2: libgda-4.1.10/libgda-ui/gdaui-enum-types.c <==

/* Generated data (by glib-mkenums) */

#include <libgda-ui/libgda-ui.h>
#include <glib-object.h>

/* enumerations from "gdaui-basic-form.h" */
GType
gdaui_basic_form_part_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GDAUI_BASIC_FORM_LABELS, "GDAUI_BASIC_FORM_LABELS", "labels" },
      { GDAUI_BASIC_FORM_ENTRIES, "GDAUI_BASIC_FORM_ENTRIES", "entries" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GdauiBasicFormPart", values);
  }
  return etype;
}

/* enumerations from "gdaui-data-proxy.h" */
GType
gdaui_data_proxy_write_mode_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GDAUI_DATA_PROXY_WRITE_ON_DEMAND, "GDAUI_DATA_PROXY_WRITE_ON_DEMAND", "demand" },
      { GDAUI_DATA_PROXY_WRITE_ON_ROW_CHANGE, "GDAUI_DATA_PROXY_WRITE_ON_ROW_CHANGE", "row-change" },
      { GDAUI_DATA_PROXY_WRITE_ON_VALUE_ACTIVATED, "GDAUI_DATA_PROXY_WRITE_ON_VALUE_ACTIVATED", "value-activated" },
      { GDAUI_DATA_PROXY_WRITE_ON_VALUE_CHANGE, "GDAUI_DATA_PROXY_WRITE_ON_VALUE_CHANGE", "value-change" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GdauiDataProxyWriteMode", values);
  }
  return etype;
}

/* enumerations from "gdaui-data-proxy-info.h" */
GType
gdaui_data_proxy_info_flag_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GFlagsValue values[] = {
      { GDAUI_DATA_PROXY_INFO_NONE, "GDAUI_DATA_PROXY_INFO_NONE", "none" },
      { GDAUI_DATA_PROXY_INFO_CURRENT_ROW, "GDAUI_DATA_PROXY_INFO_CURRENT_ROW", "current-row" },
      { GDAUI_DATA_PROXY_INFO_ROW_MODIFY_BUTTONS, "GDAUI_DATA_PROXY_INFO_ROW_MODIFY_BUTTONS", "row-modify-buttons" },
      { GDAUI_DATA_PROXY_INFO_ROW_MOVE_BUTTONS, "GDAUI_DATA_PROXY_INFO_ROW_MOVE_BUTTONS", "row-move-buttons" },
      { GDAUI_DATA_PROXY_INFO_CHUNCK_CHANGE_BUTTONS, "GDAUI_DATA_PROXY_INFO_CHUNCK_CHANGE_BUTTONS", "chunck-change-buttons" },
      { GDAUI_DATA_PROXY_INFO_NO_FILTER, "GDAUI_DATA_PROXY_INFO_NO_FILTER", "no-filter" },
      { 0, NULL, NULL }
    };
    etype = g_flags_register_static ("GdauiDataProxyInfoFlag", values);
  }
  return etype;
}

/* enumerations from "gdaui-enums.h" */
GType
gdaui_action_mode_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GFlagsValue values[] = {
      { GDAUI_ACTION_NAVIGATION_ARROWS, "GDAUI_ACTION_NAVIGATION_ARROWS", "navigation-arrows" },
      { GDAUI_ACTION_NAVIGATION_SCROLL, "GDAUI_ACTION_NAVIGATION_SCROLL", "navigation-scroll" },
      { GDAUI_ACTION_MODIF_AUTO_COMMIT, "GDAUI_ACTION_MODIF_AUTO_COMMIT", "modif-auto-commit" },
      { GDAUI_ACTION_MODIF_COMMIT_IMMEDIATE, "GDAUI_ACTION_MODIF_COMMIT_IMMEDIATE", "modif-commit-immediate" },
      { GDAUI_ACTION_ASK_CONFIRM_UPDATE, "GDAUI_ACTION_ASK_CONFIRM_UPDATE", "ask-confirm-update" },
      { GDAUI_ACTION_ASK_CONFIRM_DELETE, "GDAUI_ACTION_ASK_CONFIRM_DELETE", "ask-confirm-delete" },
      { GDAUI_ACTION_ASK_CONFIRM_INSERT, "GDAUI_ACTION_ASK_CONFIRM_INSERT", "ask-confirm-insert" },
      { GDAUI_ACTION_REPORT_ERROR, "GDAUI_ACTION_REPORT_ERROR", "report-error" },
      { 0, NULL, NULL }
    };
    etype = g_flags_register_static ("GdauiActionMode", values);
  }
  return etype;
}
GType
gdaui_action_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GDAUI_ACTION_NEW_DATA, "GDAUI_ACTION_NEW_DATA", "new-data" },
      { GDAUI_ACTION_WRITE_MODIFIED_DATA, "GDAUI_ACTION_WRITE_MODIFIED_DATA", "write-modified-data" },
      { GDAUI_ACTION_DELETE_SELECTED_DATA, "GDAUI_ACTION_DELETE_SELECTED_DATA", "delete-selected-data" },
      { GDAUI_ACTION_UNDELETE_SELECTED_DATA, "GDAUI_ACTION_UNDELETE_SELECTED_DATA", "undelete-selected-data" },
      { GDAUI_ACTION_RESET_DATA, "GDAUI_ACTION_RESET_DATA", "reset-data" },
      { GDAUI_ACTION_MOVE_FIRST_RECORD, "GDAUI_ACTION_MOVE_FIRST_RECORD", "move-first-record" },
      { GDAUI_ACTION_MOVE_PREV_RECORD, "GDAUI_ACTION_MOVE_PREV_RECORD", "move-prev-record" },
      { GDAUI_ACTION_MOVE_NEXT_RECORD, "GDAUI_ACTION_MOVE_NEXT_RECORD", "move-next-record" },
      { GDAUI_ACTION_MOVE_LAST_RECORD, "GDAUI_ACTION_MOVE_LAST_RECORD", "move-last-record" },
      { GDAUI_ACTION_MOVE_FIRST_CHUNCK, "GDAUI_ACTION_MOVE_FIRST_CHUNCK", "move-first-chunck" },
      { GDAUI_ACTION_MOVE_PREV_CHUNCK, "GDAUI_ACTION_MOVE_PREV_CHUNCK", "move-prev-chunck" },
      { GDAUI_ACTION_MOVE_NEXT_CHUNCK, "GDAUI_ACTION_MOVE_NEXT_CHUNCK", "move-next-chunck" },
      { GDAUI_ACTION_MOVE_LAST_CHUNCK, "GDAUI_ACTION_MOVE_LAST_CHUNCK", "move-last-chunck" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GdauiAction", values);
  }
  return etype;
}

/* enumerations from "gdaui-login.h" */
GType
gdaui_login_mode_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GFlagsValue values[] = {
      { GDA_UI_LOGIN_ENABLE_CONTROL_CENTRE_MODE, "GDA_UI_LOGIN_ENABLE_CONTROL_CENTRE_MODE", "enable-control-centre-mode" },
      { GDA_UI_LOGIN_HIDE_DSN_SELECTION_MODE, "GDA_UI_LOGIN_HIDE_DSN_SELECTION_MODE", "hide-dsn-selection-mode" },
      { GDA_UI_LOGIN_HIDE_DIRECT_CONNECTION_MODE, "GDA_UI_LOGIN_HIDE_DIRECT_CONNECTION_MODE", "hide-direct-connection-mode" },
      { 0, NULL, NULL }
    };
    etype = g_flags_register_static ("GdauiLoginMode", values);
  }
  return etype;
}

/* Generated data ends here */
